@@ -2,7 +2,7 @@
 
 #' @importFrom grDevices adjustcolor rainbow rgb
 #' @importFrom graphics abline boxplot legend lines par plot points segments text matplot title axis mtext
-#' @importFrom stats coef cor lm na.omit sd median complete.cases resid uniroot aggregate density hat
+#' @importFrom stats coef cor lm na.omit sd median complete.cases resid uniroot aggregate density hat qnorm
 #' @import rgl
 #' @import data.table
 #' @import stringr
@@ -20,7 +20,7 @@
       "Coefficient","X.Lower.Range","X.Upper.Range","y.hat","interval",
       "NNS.ID","max.x1","max.x2","min.x1","min.x2","counts",
       "Period","Coefficient.of.Variance","Variable.Coefficient.of.Variance",
-      "i.x","i.y","q_new","x.x","x.y"
+      "i.x","i.y","q_new","x.x","x.y","standard.errors"
     ))
   invisible()
 }
